/*************************************************************************/
/* Title : APIC22 Asynchronous DPRAM Interface Sample Circuit            */
/*                                                                       */
/*      Language         :Verilog-HDL                                    */
/*      Module           :a22smp2.v(Top Module)                          */
/*      Description      :Async Dual-Port RAM Interface(256Kbyte)        */
/*      APIC22 Local Sets:32Bit Mux Mode/Async LCLK                      */
/*                                                                       */
/*      Note : 1.񓯊DPRAMƂ̃C^tF[Xs߂̉HłB   */
/*               32Bitf[^ł̃o[Xg]T|[gĂ܂B     */
/*             2.W[(lb_pad/dp_pad)̓|[gXĝ݂`      */
/*               Ă܂BgpfoCXI/Oobt@NbN  */
/*               obt@}ĂB                            */
/*             3.gpDPRAM̓lAKvă^C~O     */
/*               ĂB                                      */
/*                                                                       */
/*                                      ADTEK System Science Co.,Ltd.    */
/*                                      URL   :http://www.adtek.co.jp    */
/*                                      E-mail:apic22@adtek.co.jp        */
/*                                      Last Update:2001/12/10           */
/*************************************************************************/

`include "adpif_define.v"

module a22smp2 (
			// APIC22 Local Bus Signals
			LB_LAD,
			LB_XLFRAME,
			LB_MXIO,
			LB_RXW,
			LB_XLRDY,
			// DPRAM Bus Signals
			DP_A,
			DP_XSEM,
			DP_XCE,
			DP_XOE,
			DP_XWE,
			DP_XBUSY,
			// System Signals
			LB_XLRESET,
			LB_LCLK
			) ;

/* APIC22 Local Bus Signals */
input	[`DEF_LBA-1:0]	LB_LAD ;// Address/Data Mux Bus
input			LB_XLFRAME ;	// Local Frame
input			LB_MXIO ;		// Memory/IO Select
input			LB_RXW ;		// Read/Write Select
output			LB_XLRDY ;		// In/Out Ready

/* DPRAM Bus Signals */
output	[`DEF_DPA-1:0]	DP_A ;	// DPRAM Address
output			DP_XSEM ;		// DPRAM Semaphore Enable
output			DP_XCE ;		// DPRAM Chip Enable
output			DP_XOE ;		// DPRAM Data Output Enable
output			DP_XWE ;		// DPRAM Data Write Enable
input			DP_XBUSY ;		// DPRAM Busy Signal

/* System Signals */
input			LB_XLRESET ;	// Local Reset
input			LB_LCLK ;		// Local Clock


/* Async DPRAM Control Module Instantiated [Begin] */
// Wire Define
wire	[`DEF_LBA-1:0]	lad ;
wire			xlframe ;
wire			m_xio ;
wire			r_xw ;
wire			xlrdy ;	
wire			xlrdy_oe ;
wire	[`DEF_DPA-1:0]	dpaddr ;
wire			xdpsem ;
wire			xdpce ;
wire			xdpoe ;
wire			xdpwe ;
wire			xdpbusy ;
wire			xlreset ;
wire			lclk ;

adpram_cnt adpram_cnt (
			// APIC22 Local Bus Signals
			.LAD(lad),
			.XLFRAME(xlframe),
			.M_XIO(m_xio),
			.R_XW(r_xw),
			.XLRDY(xlrdy),
			.XLRDY_OE(xlrdy_oe),
			// DPRAM Bus Signals
			.DPADDR(dpaddr),
			.XDPSEM(xdpsem),
			.XDPCE(xdpce),
			.XDPOE(xdpoe),
			.XDPWE(xdpwe),
			.XDPBUSY(xdpbusy),
			// System Signals
			.XLRESET(xlreset),
			.LCLK(lclk)
			) ;
/* Async DPRAM Control Module Instantiated [End] */


/* Local Bus PAD Module Instantiated [Begin] */
lb_pad lb_pad (
			// External Signals
			.LB_LAD(LB_LAD),
			.LB_XLFRAME(LB_XLFRAME),
			.LB_MXIO(LB_MXIO),
			.LB_RXW(LB_RXW),
			.LB_XLRDY(LB_XLRDY),
			.LB_XLRESET(LB_XLRESET),
			.LB_LCLK(LB_LCLK),
			// Internal Signals
			.LAD(lad),
			.XLFRAME(xlframe),
			.M_XIO(m_xio),
			.R_XW(r_xw),
			.XLRDY(xlrdy),
			.XLRDY_OE(xlrdy_oe),
			.XLRESET(xlreset),
			.LCLK(lclk)
			) ;
/* Local Bus PAD Module Instantiated [End] */


/* DPRAM Bus PAD Module Instantiated [Begin] */
dp_pad dp_pad (
			// External Signals
			.DP_A(DP_A),
			.DP_XSEM(DP_XSEM),
			.DP_XCE(DP_XCE),
			.DP_XOE(DP_XOE),
			.DP_XWE(DP_XWE),
			.DP_XBUSY(DP_XBUSY),
			// Internal Signals
			.DPADDR(dpaddr),
			.XDPSEM(xdpsem),
			.XDPCE(xdpce),
			.XDPOE(xdpoe),
			.XDPWE(xdpwe),
			.XDPBUSY(xdpbusy)
			) ;
/* DPRAM Bus PAD Module Instantiated [End] */


endmodule
