/*************************************************************************/
/* Title : APIC22 Synchronous DPRAM Interface Sample Circuit             */
/*                                                                       */
/*      Language         :Verilog-HDL                                    */
/*      Module           :a22smp3.v(Top Module)                          */
/*      Description      :Sync Dual-Port RAM Interface(256Kbyte)         */
/*      APIC22 Local Sets:32Bit Mux Mode/Sync LCLK                       */
/*                                                                       */
/*      Note : 1.^DPRAMƂ̃C^tF[Xs߂̉HłB   */
/*               32Bitf[^ł̃o[Xg]T|[gĂ܂B     */
/*             2.W[(lb_pad/dp_pad)̓|[gXĝ݂`      */
/*               Ă܂BgpfoCXI/Oobt@NbN  */
/*               obt@}ĂB                            */
/*             3.gpDPRAM̓lAKvă^C~O     */
/*               ĂB                                      */
/*                                                                       */
/*                                      ADTEK System Science Co.,Ltd.    */
/*                                      URL   :http://www.adtek.co.jp    */
/*                                      E-mail:apic22@adtek.co.jp        */
/*                                      Last Update:2001/12/10           */
/*************************************************************************/

module a22smp3 (
			// APIC22 Local Bus Signals
			LB_XBE,
			LB_XLFRAME,
			LB_MXIO,
			LB_RXW,
			LB_XLRDY,
			// DPRAM Bus Signals
			DP_XBE,
			DP_XCE,
			DP_XOE,
			DP_XWE,
			DP_XACEN,
			// System Signals
			LB_XLRESET,
			LB_LCLK
			) ;

/* APIC22 Local Bus Signals */
input	[3:0]	LB_XBE ;		// Byte Enable
input			LB_XLFRAME ;	// Local Frame
input			LB_MXIO ;		// Memory/IO Select
input			LB_RXW ;		// Read/Write Select
output			LB_XLRDY ;		// In/Out Ready

/* DPRAM Bus Signals */
output	[3:0]	DP_XBE ;		// DPRAM Byte Enable
output			DP_XCE ;		// DPRAM Chip Enable
output			DP_XOE ;		// DPRAM Data Output Enable
output			DP_XWE ;		// DPRAM Data Write Enable
output			DP_XACEN ;		// DPRAM Address Count Enable

/* System Signals */
input			LB_XLRESET ;	// Local Reset
input			LB_LCLK ;		// Local Clock


/* Sync DPRAM Control Module Instantiated [Begin] */
// Wire Define
wire	[3:0]	xbe ;
wire			xlframe ;
wire			m_xio ;
wire			r_xw ;
wire			xlrdy ;	
wire			xlrdy_oe ;
wire	[3:0]	xdpbe ;
wire			xdpce ;
wire			xdpoe ;
wire			xdpwe ;
wire			xdpacen ;
wire			xlreset ;
wire			lclk ;

sdpram_cnt sdpram_cnt (
			// APIC22 Local Bus Signals
			.XBE(xbe[3:0]),
			.XLFRAME(xlframe),
			.M_XIO(m_xio),
			.R_XW(r_xw),
			.XLRDY(xlrdy),
			.XLRDY_OE(xlrdy_oe),
			// DPRAM Bus Signals
			.XDPBE(xdpbe[3:0]),
			.XDPCE(xdpce),
			.XDPOE(xdpoe),
			.XDPWE(xdpwe),
			.XDPACEN(xdpacen),
			// System Signals
			.XLRESET(xlreset),
			.LCLK(lclk)
			) ;
/* Sync DPRAM Control Module Instantiated [End] */


/* Local Bus PAD Module Instantiated [Begin] */
lb_pad lb_pad (
			// External Signals
			.LB_XBE(LB_XBE[3:0]),
			.LB_XLFRAME(LB_XLFRAME),
			.LB_MXIO(LB_MXIO),
			.LB_RXW(LB_RXW),
			.LB_XLRDY(LB_XLRDY),
			.LB_XLRESET(LB_XLRESET),
			.LB_LCLK(LB_LCLK),
			// Internal Signals
			.XBE(xbe[3:0]),
			.XLFRAME(xlframe),
			.M_XIO(m_xio),
			.R_XW(r_xw),
			.XLRDY(xlrdy),
			.XLRDY_OE(xlrdy_oe),
			.XLRESET(xlreset),
			.LCLK(lclk)
			) ;
/* Local Bus PAD Module Instantiated [End] */


/* DPRAM Bus PAD Module Instantiated [Begin] */
dp_pad dp_pad (
			// External Signals
			.DP_XBE(DP_XBE[3:0]),
			.DP_XCE(DP_XCE),
			.DP_XOE(DP_XOE),
			.DP_XWE(DP_XWE),
			.DP_XACEN(DP_XACEN),
			// Internal Signals
			.XDPBE(xdpbe[3:0]),
			.XDPCE(xdpce),
			.XDPOE(xdpoe),
			.XDPWE(xdpwe),
			.XDPACEN(xdpacen)
			) ;
/* DPRAM Bus PAD Module Instantiated [End] */


endmodule
