//------------------------------------------------------------------------------//
//				APIC22DK/CPCI_MAIN Module							//
//					ADTEK SYSTEM SCIENCE CO.,LTD.						//
//				Since 2005/07/20  LAST UPDATE 2005/11/01				//			
//						Release 1.00								//
//						Neme:T.Mizuo								//			
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//	Module	n  -> Active Low Signal									//
//------------------------------------------------------------------------------//


module DK_MAIN

	(	n_PCI_RST_i,
		n_PCI_RST_o,
		n_BD_SEL,
		n_HEALTHY,
		M66EN,
		PCIXCAP,
		n_PWGOOD,
		P_GND
	);



//-----------------------Input Signal Definition--------------------------------//

	input	n_PCI_RST_i ;			// PCI_RST M
	input	n_PWGOOD ;			// LTC1646 M
	input	n_BD_SEL ;			// BD_SEL@Mo

//-----------------------Output Signal Definition-------------------------------//

	output	n_PCI_RST_o ;			// PCI_RST Mo
	output	n_HEALTHY ;			// HEALTHY Mo
	output	[4:0]P_GND ;			// Programable Grand

//-----------------------Inout Signal Definition--------------------------------//

 
	inout	M66EN ;				// M66EN @Mo
	inout	[2:0]PCIXCAP ;			// PCIXCAP Mo
								// ͓dKi𖞂3

//-----------------------Wire Signal Definition---------------------------------//

	wire		RST 			= !n_PCI_RST_i	;
	assign	n_PCI_RST_o	= !RST ;

//------------------------------------------------------------------------------//

	wire		[4:0] P_GND ;				
	assign 	P_GND 		= 5'b0_0000 ;

//------------------------------------------------------------------------------//

	wire		xcap ;
	assign 	xcap	= CAP ( PCIXCAP ) ;

	function 	CAP ;

		input [ 2:0 ] PCIXCAP ;

		begin
			case ( PCIXCAP )
				3'b000	: CAP = 1'b0 ;
				3'b111	: CAP = 1'b1 ;
				default	: CAP = 1'bZ ;
			endcase
		end
	endfunction

//------------------------------------------------------------------------------//
//	M66EN@`												//
//------------------------------------------------------------------------------//

	reg 		REG ;

	always @(  posedge n_BD_SEL or posedge RST ) begin

		if ( n_BD_SEL ==1 )  begin
			REG	<= 1'b1 ;

		end else if ( RST == 1 ) begin
			REG	<= 1'b0 ;

		end else begin
			REG	<= REG ;

		end
	  
	end


//------------------------------------------------------------------------------//
//	M66EN X[Xe[g`											//
//------------------------------------------------------------------------------//

	assign	M66EN = ( REG )? 1'bz : 0 ;

//------------------------------------------------------------------------------//
//	OR1@`													//
//------------------------------------------------------------------------------//

	wire		or1 ;
	assign	or1	= ~( n_PCI_RST_i | n_BD_SEL ) ;

//------------------------------------------------------------------------------//
//	PCIXCAP X[Xe[g`										//
//------------------------------------------------------------------------------//

	assign	PCIXCAP [2:0]  = (  or1 )? 0 : 3'bZZZ ;

//------------------------------------------------------------------------------//
//	OR2@`													//
//------------------------------------------------------------------------------//

	wire		or2;
	assign	or2	= ( M66EN | xcap ) ;


//------------------------------------------------------------------------------//
//	Transparent Latch `										//
//------------------------------------------------------------------------------//

	reg		TLREG ;
	
	always @ ( posedge RST or posedge n_BD_SEL  ) begin

		if ( RST == 1 ) begin
			TLREG	<= 0 ;

		end else if ( n_BD_SEL == 1 ) begin
			TLREG	<= or2 ;

		end else begin
			TLREG	<= TLREG ;

		end

	end

//------------------------------------------------------------------------------//
//	nHEALTHY `												//
//------------------------------------------------------------------------------//

	assign	n_HEALTHY = ( TLREG )?  1'hZ : ( ( n_PWGOOD ? 1'hZ : 0 ) )  ;

//------------------------------------------------------------------------------//

endmodule

